package com.ruoyi.invest.service;

import com.ruoyi.invest.domain.TProjectRecord;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 跟进记录Service接口
 * 
 * @author ruoyi
 * @date 2024-02-21
 */
public interface ITProjectRecordService 
{
    /**
     * 查询跟进记录
     * 
     * @param id 跟进记录主键
     * @return 跟进记录
     */
    public TProjectRecord selectTProjectRecordById(String id);

    /**
     * 查询跟进记录列表
     * 
     * @param tProjectRecord 跟进记录
     * @return 跟进记录集合
     */
    public List<TProjectRecord> selectTProjectRecordList(TProjectRecord tProjectRecord);

    /**
     * 新增跟进记录
     * 
     * @param tProjectRecord 跟进记录
     * @return 结果
     */
    public int insertTProjectRecord(TProjectRecord tProjectRecord);

    /**
     * 修改跟进记录
     * 
     * @param tProjectRecord 跟进记录
     * @return 结果
     */
    public int updateTProjectRecord(TProjectRecord tProjectRecord);

    /**
     * 批量删除跟进记录
     * 
     * @param ids 需要删除的跟进记录主键集合
     * @return 结果
     */
    public int deleteTProjectRecordByIds(String[] ids);

    /**
     * 删除跟进记录信息
     * 
     * @param id 跟进记录主键
     * @return 结果
     */
    public int deleteTProjectRecordById(String id);

    /**
     * 批量删除跟进记录(修改del_flag状态)
     *
     * @param ids 需要删除的跟进记录主键集合
     * @return 结果
     */
    public int updateTProjectRecordByIds(String[] ids);

    /**
     * 根据项目ID获取跟进记录
     * @param porjectId
     * @return
     */
    public List<TProjectRecord> listProjectId(String porjectId);
}
